----------------------------------------------------------------------------------
-- Company: UAM 
-- Design Name: bin_reader_ctrl
-- Project Name: bin_reader
-- Description: 
--   Controls the binary reader operation
-- Dependencies: 
--   (none)
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

-------------------------------------------------------------------------------
-- Entity

entity bin_reader_ctrl is
  port (
        Clk         : in  std_logic;
        Reset       : in  std_logic;
        Switches    : in  std_logic_vector (7 downto 0);
        MemWe       : out std_logic;
        MemAddress  : out std_logic_vector (7 downto 0);
        EnableCount : out std_logic
       );
end bin_reader_ctrl;

-------------------------------------------------------------------------------
-- Architecture

architecture Behavioral of bin_reader_ctrl is

 signal addr : std_logic_vector (7 downto 0);
 signal ready : std_logic;
 
begin

  process (Clk, Reset)
  begin
    if Reset = '1' then
      ready <= '0';
      MemWe <= '1';
      EnableCount <= '1';
      addr <= (others => '0');
    elsif rising_edge(Clk) then
      if ready = '0' then
        -- 1st step: make the counters run to write the 256 7-segment
        --   codes into memory:
        if addr /= x"FF" then
          addr <= addr + 1;
        else
          ready <= '1';
          MemWe <= '0';
          EnableCount <= '0';
        end if;
      else
        -- 2nd step: let the switches control the memory to read the
        --   corresponding codes:
        addr <= Switches;
      end if;
    end if;
  
  end process;

  MemAddress <= addr;

end Behavioral;

